<?php

namespace App\Controller\Admin;

use App\Entity\Booking;
use App\Repository\EmployeeRepository;
use Doctrine\ORM\EntityManagerInterface;
use Doctrine\ORM\QueryBuilder;
use EasyCorp\Bundle\EasyAdminBundle\Collection\FieldCollection;
use EasyCorp\Bundle\EasyAdminBundle\Collection\FilterCollection;
use EasyCorp\Bundle\EasyAdminBundle\Config\Action;
use EasyCorp\Bundle\EasyAdminBundle\Config\Actions;
use EasyCorp\Bundle\EasyAdminBundle\Config\Crud;
use EasyCorp\Bundle\EasyAdminBundle\Config\Filters;
use EasyCorp\Bundle\EasyAdminBundle\Controller\AbstractCrudController;
use EasyCorp\Bundle\EasyAdminBundle\Dto\EntityDto;
use EasyCorp\Bundle\EasyAdminBundle\Dto\SearchDto;
use EasyCorp\Bundle\EasyAdminBundle\Field\AssociationField;
use EasyCorp\Bundle\EasyAdminBundle\Field\CollectionField;
use EasyCorp\Bundle\EasyAdminBundle\Field\DateField;
use EasyCorp\Bundle\EasyAdminBundle\Field\DateTimeField;
use EasyCorp\Bundle\EasyAdminBundle\Field\IdField;
use EasyCorp\Bundle\EasyAdminBundle\Field\IntegerField;
use EasyCorp\Bundle\EasyAdminBundle\Field\MoneyField;
use EasyCorp\Bundle\EasyAdminBundle\Field\TextField;
use EasyCorp\Bundle\EasyAdminBundle\Filter\EntityFilter;
use PhpParser\Node\Stmt\Label;

class BookingCrudController extends AbstractCrudController
{
    public function __construct(private EmployeeRepository $employeeRepository){}
    public static function getEntityFqcn(): string
    {
        return Booking::class;
    }
    public function configureCrud(Crud $crud): Crud
    {
        return $crud
            ->setSearchFields(['numdossier'])
            ->setPageTitle('index', 'Liste des %entity_label_plural%')
            ->setEntityLabelInSingular('Votre réservation')
            ->setEntityLabelInPlural('réservations')
            ->setDateTimeFormat('dd/MM/yyyy à HH:mm')
            ;
    }
    public function configureFields(string $pageName): iterable
    {
        $user=$this->getUser();
        $companyId = $user->getCompany()->getId();
        return [
            AssociationField::new('company', 'Entreprise')->setDisabled(true),
            IdField::new('numdossier', 'N°')->setDisabled(true),
            DateTimeField::new('dateOfBooking','Date de réservation')->setDisabled(true),
            AssociationField::new('schedule', 'Planning voyage')->setQueryBuilder(fn (QueryBuilder $queryBuilder) =>
                $queryBuilder->where('entity.company ='.$companyId))
                ->setDisabled(true),
            IntegerField::new('numberOfSeats','Sièges')->setDisabled(true),
            MoneyField::new('totalAmount','Facturé')->setCurrency('XAF')
                                        ->setDisabled(true)
                                        ->setCustomOption('storedAsCents', false)
                                        ->setNumDecimals(0),
            TextField::new('facture', 'facture'),
            CollectionField::new('passager', 'Passagers')->renderExpanded(true),
            AssociationField::new('user','Client')->setDisabled(true),
            //MoneyField::new('fareAmount','Tarif'),
                                        

            //DateTimeField::new('createdAt')->setDisabled(true),
            //DateTimeField::new('updatedAt')->setDisabled(true),
        ];
    }

    public function configureActions(Actions $actions): Actions
    {
    return $actions
        ->disable(Action::NEW, Action::EDIT, Action::DELETE);
    }

    public function createIndexQueryBuilder(SearchDto $searchDto, EntityDto $entityDto, FieldCollection $fields, FilterCollection $filters): QueryBuilder
    {
        $user=$this->getUser();
        $companyId = $user->getCompany()->getId();

        $queryBuilder=parent::createIndexQueryBuilder($searchDto, $entityDto, $fields, $filters);
        if (!$this->isGranted('ROLE_SUPER_ADMIN')){
            $queryBuilder->where('entity.company = (:company_0)')
                        ->setParameter('company_0', $companyId);
        }
        $queryBuilder->orderBy('entity.dateOfBooking', 'DESC');
        return $queryBuilder;
    }
    
     public function configureFilters(Filters $filters): Filters
     {
        if ($this->isGranted('ROLE_SUPER_ADMIN')){
            return $filters
            ->add('dateOfBooking')
            ->add('user')
            ->add('company')
         ;
        }else{
            return $filters;
        }
    }
}
