<?php

namespace App\Controller\Admin;

use App\Entity\Booking;
use App\Repository\BookingRepository;
use App\Repository\PassagerRepository;
use App\Repository\PaymentRepository;
use Dompdf\Dompdf;
use Dompdf\Options;
use Knp\Component\Pager\PaginatorInterface;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\Form\Extension\Core\Type\DateType;
use Symfony\Component\Form\Extension\Core\Type\SubmitType;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\Security\Http\Attribute\IsGranted;

#[IsGranted("ROLE_ADMIN")]
class ManifesteController extends AbstractController
{
    #[Route('/manifeste', name: 'app_manifeste', methods: ['GET', 'POST'])]
    public function manifeste(Request $request,
            PassagerRepository $passagerRepository,
            PaginatorInterface $paginator): Response
    {

        $form = $this->createFormBuilder()
            ->add('date', DateType::class, [
                'widget' => 'single_text',
                //'html5' => true,
                'data' => new \DateTime(),
                //'attr'   => ['min' => (new \DateTime())->format('Y-m-d')],
                'mapped'=> false,
                'label' => false,
                'required' => true
            ])
            ->add('send', SubmitType::class,[
                'label' => 'Valider',
                'label_html' => true,
                'attr' =>[
                    'class'=>'btn btn-primary',
                    'placeholder' => 'OK',
                ],
            
            ])
            ->getForm();

        $form->handleRequest($request);
        $employee = $this->getUser();
        $companyId = $employee->getCompany()->getId();
        $date = (new \DateTime())->format('Y-m-d');

        if ($form->isSubmitted() && $form->isValid()) {
            $dataform = $request->request->all();
            $date = $dataform['form']['date'];
        }
        $dateManifeste = $date;
        $data = $passagerRepository->findManifesteByDate($dateManifeste, $companyId);
        $passagers = $paginator->paginate(
            $data,
            $request->query->getInt('page', 1), 25
        );
        
        //--------------------------------------------------------------------------
        return $this->render('admin/manifeste.html.twig', [
            'form'=>$form,
            'dateManifeste'=>$dateManifeste,
            'passagers' => $passagers]);
    }

    #[Route('/manifestepdf', name: 'app_manifeste_pdf', methods: ['GET', 'POST'])]
    public function manifeste_pdf(Request $request,
            PassagerRepository $passagerRepository,
            PaginatorInterface $paginator): Response
    {

       // dd($request);
$date= $request->get('date2');
//dd($date);
        $employee = $this->getUser();
        $company = $employee->getCompany();
        $companyId = $company->getId();

            // création du pdf
            $pdfOptions = new Options();
            $pdfOptions->set('defaultFont', 'Arial');
            $dompdf = new Dompdf($pdfOptions);

            $path = $this->getParameter('kernel.project_dir').'/public/assets/img/gallery/logoKD-146x112.png';
            $type = pathinfo($path, PATHINFO_EXTENSION);
            $data = file_get_contents($path);
            $logobase64 = 'data:image/' . $type . ';base64,' . base64_encode($data);

            if ($company->getImage()===null){
                $pathlogoCompany = $this->getParameter('kernel.project_dir').'/public/assets/img/company/0.jpg';
            }else{
                $pathlogoCompany = $this->getParameter('kernel.project_dir').'/public/assets/img/company/'.$company->getImage();
            }    
            $type = pathinfo($pathlogoCompany, PATHINFO_EXTENSION);
            $data = file_get_contents($pathlogoCompany);
            $logocompany64 = 'data:image/' . $type . ';base64,' . base64_encode($data);

            $passagers = $passagerRepository->findManifesteByDate($date, $companyId);
            // Retrieve the HTML generated in our twig file
            $html = $this->renderView('admin/manifeste_pdf.html.twig', [
                'passagers'=>$passagers,
                'date'=>$date,
                'company' => $company,
                'logobase64' => $logobase64,
                'logocompany64' => $logocompany64,
            ]);

            // Load HTML to Dompdf
            $dompdf->loadHtml($html);
            $dompdf->setPaper('A4', 'portrait');
            $dompdf->render();

            $dompdf->stream("mypdf.pdf", [
                "Attachment" => false
           ]);
    }


    #[Route('/report_payment', name: 'app_report_payment')]
    public function report_payment(PaymentRepository $paymentRepository)
    {   

        $user=$this->getUser();
        $company = $user->getCompany();

        // création du pdf
        $pdfOptions = new Options();
        $pdfOptions->set('defaultFont', 'Arial');
        $dompdf = new Dompdf($pdfOptions);

        $path = $this->getParameter('kernel.project_dir').'/public/assets/img/gallery/logoKD-146x112.png';
        $type = pathinfo($path, PATHINFO_EXTENSION);
        $data = file_get_contents($path);
        $logobase64 = 'data:image/' . $type . ';base64,' . base64_encode($data);

        if ($company->getImage()===null){
            $pathlogoCompany = $this->getParameter('kernel.project_dir').'/public/assets/img/company/0.jpg';
        }else{
            $pathlogoCompany = $this->getParameter('kernel.project_dir').'/public/assets/img/company/'.$company->getImage();
        }    
        $type = pathinfo($pathlogoCompany, PATHINFO_EXTENSION);
        $data = file_get_contents($pathlogoCompany);
        $logocompany64 = 'data:image/' . $type . ';base64,' . base64_encode($data);

        $payments = $paymentRepository->findBy(['company'=>$user->getCompany()->getId()], ['paymentDate'=> 'DESC']);
        $html = $this->renderView('admin/report_payment.html.twig', [
            'payments'=>$payments,
            'company'=>$user->getCompany(),
            'logobase64' => $logobase64,
            'logocompany64' => $logocompany64,
        ]);

        // Load HTML to Dompdf
        $dompdf->loadHtml($html);
        $dompdf->setPaper('A4', 'portrait');
        $dompdf->render();

       // Output the generated PDF to Browser (inline view)
        $dompdf->stream("mypdf.pdf", [
             "Attachment" => false
        ]);
    }



}
