<?php

namespace App\Controller\Admin;

use App\Entity\User;
use App\Repository\EmployeeRepository;
use Doctrine\ORM\Mapping\Builder\AssociationBuilder;
use Doctrine\ORM\QueryBuilder;
use Doctrine\ORM\EntityManagerInterface;
use EasyCorp\Bundle\EasyAdminBundle\Collection\FilterCollection;
use EasyCorp\Bundle\EasyAdminBundle\Collection\FieldCollection;
use EasyCorp\Bundle\EasyAdminBundle\Config\Filters;
use EasyCorp\Bundle\EasyAdminBundle\Controller\AbstractCrudController;
use EasyCorp\Bundle\EasyAdminBundle\Dto\EntityDto;
use EasyCorp\Bundle\EasyAdminBundle\Dto\SearchDto;
use EasyCorp\Bundle\EasyAdminBundle\Field\ArrayField;
use EasyCorp\Bundle\EasyAdminBundle\Field\AssociationField;
use EasyCorp\Bundle\EasyAdminBundle\Field\ChoiceField;
use EasyCorp\Bundle\EasyAdminBundle\Field\DateTimeField;
use EasyCorp\Bundle\EasyAdminBundle\Field\EmailField;
use EasyCorp\Bundle\EasyAdminBundle\Field\IdField;
use EasyCorp\Bundle\EasyAdminBundle\Field\TextField;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\IsGranted;
#[IsGranted('ROLE_SUPER_ADMIN')]
class UserCrudController extends AbstractCrudController
{
    public function __construct(private EmployeeRepository $employeeRepository){}
    public static function getEntityFqcn(): string
    {
        return User::class;
    }

    public function configureFields(string $pageName): iterable
    {
        return [
            TextField::new('lastname','Nom'),
            TextField::new('firstname','Prénom'),
            EmailField::new('email','Email')->hideOnForm(),
            ChoiceField::new('roles','Permissions')
                ->setChoices([
                    'Super Administrateur'=>'ROLE_SUPER_ADMIN',
                    'Administrateur' => 'ROLE_ADMIN',
                    'Editeur' =>'ROLE_EDITOR',
                    'Utilisateur' =>'ROLE_USER',
                ])
                ->setRequired(false)
                ->allowMultipleChoices(true),

            //TextField::new('password', 'Mot de passe')->onlyOnForms(),
            //TextField::new('plainPassword', 'Mot de passe')->onlyOnForms(),
        ];
    }
    public function configureFilters(Filters $filters): Filters
    {
        return $filters
           ->add('lastname')
        ;
    }

    public function createIndexQueryBuilder(SearchDto $searchDto, EntityDto $entityDto, FieldCollection $fields, FilterCollection $filters): QueryBuilder
    {
        $user=$this->getUser();
        $companyId = $user->getCompany()->getId();
        $queryBuilder=parent::createIndexQueryBuilder($searchDto, $entityDto, $fields, $filters);
        $queryBuilder->orderBy('entity.lastname','ASC')
                     ->addOrderBy('entity.firstname','ASC');
        return $queryBuilder;
    }
}
