<?php

namespace App\Entity;

use App\Entity\Traits\TimestampsTrait;
use App\Repository\CompanyRepository;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Mapping as ORM;
use Doctrine\ORM\Mapping\HasLifecycleCallbacks;
use Doctrine\ORM\Mapping\JoinTable;

#[ORM\Entity(repositoryClass: CompanyRepository::class)]
#[HasLifecycleCallbacks]
class Company
{
    use TimestampsTrait;


    #[ORM\Id]
    #[ORM\GeneratedValue]
    #[ORM\Column]
    private ?int $id = null;

    #[ORM\Column(length: 50)]
    private ?string $name = null;

    #[ORM\Column(length: 200)]
    private ?string $address = null;

    #[ORM\Column(length: 100)]
    private ?string $email = null;

    #[ORM\Column(length: 20)]
    private ?string $telephone = null;

    #[ORM\Column(length: 255, nullable: true)]
    private ?string $image = null;

    #[ORM\OneToMany(mappedBy: 'company', targetEntity: Tarif::class)]
    private Collection $tarifs;

    #[ORM\OneToMany(mappedBy: 'company', targetEntity: TypeTarif::class)]
    private Collection $typeTarifs;

    #[ORM\OneToMany(mappedBy: 'company', targetEntity: Employee::class)]
    private Collection $employees;

    #[ORM\OneToMany(mappedBy: 'company', targetEntity: Payment::class)]
    private Collection $payments;

    #[ORM\OneToMany(mappedBy: 'company', targetEntity: Agence::class)]
    private Collection $agences;

    #[ORM\OneToMany(mappedBy: 'company', targetEntity: CompanyVille::class)]
    private Collection $companyVilles;

    public function __construct()
    {
        $this->tarifs = new ArrayCollection();
        $this->typeTarifs = new ArrayCollection();
        $this->employees = new ArrayCollection();
        $this->payments = new ArrayCollection();
        $this->agences = new ArrayCollection();
        $this->companyVilles = new ArrayCollection();
    }

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getName(): ?string
    {
        return $this->name;
    }

    public function setName(string $name): self
    {
        $this->name = $name;

        return $this;
    }

    public function getAddress(): ?string
    {
        return $this->address;
    }

    public function setAddress(string $address): self
    {
        $this->address = $address;

        return $this;
    }

    public function getEmail(): ?string
    {
        return $this->email;
    }

    public function setEmail(string $email): self
    {
        $this->email = $email;

        return $this;
    }

    public function getTelephone(): ?string
    {
        return $this->telephone;
    }

    public function setTelephone(string $telephone): self
    {
        $this->telephone = $telephone;

        return $this;
    }

    public function __toString() {
        return $this->name;
    }

    public function getImage(): ?string
    {
        return $this->image;
    }

    public function setImage(?string $image): self
    {
        $this->image = $image;

        return $this;
    }

    /**
     * @return Collection<int, Tarif>
     */
    public function getTarifs(): Collection
    {
        return $this->tarifs;
    }

    public function addTarif(Tarif $tarif): static
    {
        if (!$this->tarifs->contains($tarif)) {
            $this->tarifs->add($tarif);
            $tarif->setCompany($this);
        }

        return $this;
    }

    public function removeTarif(Tarif $tarif): static
    {
        if ($this->tarifs->removeElement($tarif)) {
            // set the owning side to null (unless already changed)
            if ($tarif->getCompany() === $this) {
                $tarif->setCompany(null);
            }
        }

        return $this;
    }

    /**
     * @return Collection<int, TypeTarif>
     */
    public function getTypeTarifs(): Collection
    {
        return $this->typeTarifs;
    }

    public function addTypeTarif(TypeTarif $typeTarif): static
    {
        if (!$this->typeTarifs->contains($typeTarif)) {
            $this->typeTarifs->add($typeTarif);
            $typeTarif->setCompany($this);
        }

        return $this;
    }

    public function removeTypeTarif(TypeTarif $typeTarif): static
    {
        if ($this->typeTarifs->removeElement($typeTarif)) {
            // set the owning side to null (unless already changed)
            if ($typeTarif->getCompany() === $this) {
                $typeTarif->setCompany(null);
            }
        }

        return $this;
    }

    /**
     * @return Collection<int, Employee>
     */
    public function getEmployees(): Collection
    {
        return $this->employees;
    }

    public function addEmployee(Employee $employee): static
    {
        if (!$this->employees->contains($employee)) {
            $this->employees->add($employee);
            $employee->setCompany($this);
        }

        return $this;
    }

    public function removeEmployee(Employee $employee): static
    {
        if ($this->employees->removeElement($employee)) {
            // set the owning side to null (unless already changed)
            if ($employee->getCompany() === $this) {
                $employee->setCompany(null);
            }
        }

        return $this;
    }

    /**
     * @return Collection<int, Payment>
     */
    public function getPayments(): Collection
    {
        return $this->payments;
    }

    public function addPayment(Payment $payment): static
    {
        if (!$this->payments->contains($payment)) {
            $this->payments->add($payment);
            $payment->setCompany($this);
        }

        return $this;
    }

    public function removePayment(Payment $payment): static
    {
        if ($this->payments->removeElement($payment)) {
            // set the owning side to null (unless already changed)
            if ($payment->getCompany() === $this) {
                $payment->setCompany(null);
            }
        }

        return $this;
    }

    /**
     * @return Collection<int, Agence>
     */
    public function getAgences(): Collection
    {
        return $this->agences;
    }

    public function addAgence(Agence $agence): static
    {
        if (!$this->agences->contains($agence)) {
            $this->agences->add($agence);
            $agence->setCompany($this);
        }

        return $this;
    }

    public function removeAgence(Agence $agence): static
    {
        if ($this->agences->removeElement($agence)) {
            // set the owning side to null (unless already changed)
            if ($agence->getCompany() === $this) {
                $agence->setCompany(null);
            }
        }

        return $this;
    }

    /**
     * @return Collection<int, CompanyVille>
     */
    public function getCompanyVilles(): Collection
    {
        return $this->companyVilles;
    }

    public function addCompanyVille(CompanyVille $companyVille): static
    {
        if (!$this->companyVilles->contains($companyVille)) {
            $this->companyVilles->add($companyVille);
            $companyVille->setCompany($this);
        }

        return $this;
    }

    public function removeCompanyVille(CompanyVille $companyVille): static
    {
        if ($this->companyVilles->removeElement($companyVille)) {
            // set the owning side to null (unless already changed)
            if ($companyVille->getCompany() === $this) {
                $companyVille->setCompany(null);
            }
        }

        return $this;
    }


}
