<?php

namespace App\Entity;

use App\Entity\Traits\TimestampsTrait;
use App\Repository\ScheduleRepository;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\DBAL\Types\Types;
use Doctrine\ORM\Mapping as ORM;
use Doctrine\ORM\Mapping\HasLifecycleCallbacks;

// /**
//  * Schedule
//  *
//  * ORM\Table(name="schedule", indexes={@ORM\Index(name="bus_id", columns={"bus_id", "driver_id", "employee_id"}), @ORM\Index(name="driver_id", columns={"driver_id"}), @ORM\Index(name="employee_id", columns={"employee_id"}), @ORM\Index(name="IDX_EF3347972546731D", columns={"bus_id"})})
//  * ORM\Entity
//  */
#[ORM\Table(name: "schedule")]
#[ORM\Entity(repositoryClass: ScheduleRepository::class)]
#[HasLifecycleCallbacks]
class Schedule
{
    use TimestampsTrait;
    /**
     * @var int
     */
    #[
        ORM\Column(name: "id", type: Types::INTEGER, nullable: false),
        ORM\Id,
        ORM\GeneratedValue(strategy: "IDENTITY")
    ]
    private int $id;

      /**
     * @var \DateTime
     */
    #[ORM\Column(name: "schedule_date", type: Types::DATETIME_MUTABLE, nullable: false)]
    private \DateTime $scheduleDate;

    /**
     * @var \DateTime
     */

    #[ORM\Column(name: "departure_time", type: Types::DATETIME_MUTABLE, nullable: false)]
    private \DateTime $departureTime;

    /**
     * @var \DateTime
     */
    #[ORM\Column(name: "estimated_arrival_time", type: Types::DATETIME_MUTABLE, nullable: false)]
    private \DateTime $estimatedArrivalTime;

    /**
     * @var string
     */
    #[ORM\Column(name: "remarks", type: Types::STRING, length: 100, nullable: false)]
    private $remarks;

    /**
    * @var Company
    */
    #[
        ORM\ManyToOne(targetEntity: Company::class),
        ORM\JoinColumn(name: "company_id", referencedColumnName: "id")
    ]
    private Company $company;
 

    /**
     * @var Employee
     */
    #[
        ORM\ManyToOne(targetEntity: Employee::class),
        ORM\JoinColumn(name: "employee_id", referencedColumnName: "id")
    ]
    private $employee;

    /**
     * @var Bus
     */
    #[
        ORM\ManyToOne(targetEntity: Bus::class),
        ORM\JoinColumn(name: "bus_id", referencedColumnName: "id")
    ]
    private $bus;

    #[ORM\ManyToOne(inversedBy: 'schedules')]
    private ?TypeTarif $typeTarif = null;

    #[ORM\Column]
    private ?int $seats = null;

    #[ORM\ManyToOne(inversedBy: 'schedules')]
    private ?Ville $depart = null;

    #[ORM\ManyToOne(inversedBy: 'schedules')]
    private ?Ville $arrivee = null;

    #[ORM\Column]
    private ?bool $active = null;

    public function getId(): ?int
    {
        return $this->id;
    }
    public function getScheduleDate(): ?\DateTimeInterface
    {
        return $this->scheduleDate;
    }

    public function setScheduleDate(\DateTimeInterface $scheduleDate): self
    {
        $this->scheduleDate = $scheduleDate;

        return $this;
    }

    public function getDepartureTime(): ?\DateTimeInterface
    {
        return $this->departureTime;
    }

    public function setDepartureTime(\DateTimeInterface $departureTime): self
    {
        $this->departureTime = $departureTime;

        return $this;
    }

    public function getEstimatedArrivalTime(): ?\DateTimeInterface
    {
        return $this->estimatedArrivalTime;
    }

    public function setEstimatedArrivalTime(\DateTimeInterface $estimatedArrivalTime): self
    {
        $this->estimatedArrivalTime = $estimatedArrivalTime;

        return $this;
    }

    public function getRemarks(): ?string
    {
        return $this->remarks;
    }

    public function setRemarks(string $remarks): self
    {
        $this->remarks = $remarks;

        return $this;
    }


    public function getCompany(): ?Company
    {
        return $this->company;
    }

    public function setCompany(?Company $company): self
    {
        $this->company = $company;

        return $this;
    }

    public function getEmployee(): ?Employee
    {
        return $this->employee;
    }

    public function setEmployee(?Employee $employee): self
    {
        $this->employee = $employee;

        return $this;
    }

    public function getBus(): ?Bus
    {
        return $this->bus;
    }

    public function setBus(?Bus $bus): self
    {
        $this->bus = $bus;

        return $this;
    }
    public function __toString() {
        $dat = date_format ($this->scheduleDate, 'd/m/Y');
        return $dat. ' : '. $this->depart. ' > '.$this->arrivee;
    }

    public function getTypeTarif(): ?TypeTarif
    {
        return $this->typeTarif;
    }

    public function setTypeTarif(?TypeTarif $typeTarif): static
    {
        $this->typeTarif = $typeTarif;

        return $this;
    }

    public function getSeats(): ?int
    {
        return $this->seats;
    }

    public function setSeats(int $seats): static
    {
        $this->seats = $seats;

        return $this;
    }

    public function getDepart(): ?Ville
    {
        return $this->depart;
    }

    public function setDepart(?Ville $depart): static
    {
        $this->depart = $depart;

        return $this;
    }

    public function getArrivee(): ?Ville
    {
        return $this->arrivee;
    }

    public function setArrivee(?Ville $arrivee): static
    {
        $this->arrivee = $arrivee;

        return $this;
    }

    public function getActive(): ?bool
    {
        return $this->active;
    }

    public function setActive(bool $active): static
    {
        $this->active = $active;

        return $this;
    }
   
}
