<?php

namespace App\Form;

use App\Entity\Schedule;
use App\Entity\Stopover;
use App\Repository\ScheduleRepository;
use App\Repository\StopoverRepository;
use Doctrine\ORM\Query\Expr\Join;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\DateType;
use Symfony\Bridge\Doctrine\Form\Type\EntityType;
use Symfony\Component\Form\Extension\Core\Type\ChoiceType;
use Symfony\Component\Form\Extension\Core\Type\SubmitType;
use Symfony\Component\Form\Extension\Core\Type\TimeType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\Form\FormEvent;
use Symfony\Component\Form\FormEvents;
use Symfony\Component\Form\FormFactoryInterface;
use Symfony\Component\Form\FormInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;

class SearchType extends AbstractType
{
    private FormFactoryInterface $factory;
    public function __construct(private scheduleRepository $scheduleRepository){}

    public function buildForm(FormBuilderInterface $builder, array $options): void
    {
        //$initData = $this->scheduleRepository->findOneBy(['depart'=> 1]);
       // $initData = new Schedule();
        $builder
            ->add('depart', EntityType::class, [
                //'data'=> $initData,
                'placeholder' => 'Sélectionner le départ',
                'class' => Schedule::class,
                'query_builder' => function (ScheduleRepository $s) {
                    return $s->createQueryBuilder('s')
                        ->join('s.depart', 'vi')
                        ->orderBy('vi.name','ASC')
                        ->groupBy('vi.name')
//                        ->where("s.scheduleDate >= '2023-11-01'")
                        ->where("s.scheduleDate >= '". (new \DateTime())->format('Y-m-d')."'")
                        ->andWhere('s.active = 1');
                },
                'choice_label'  => 'depart.name',
                'choice_value'  => 'depart.id',
                'mapped'=> false,
                'label' => 'Départ',
                'required' => true
            ])
            ->add('date', DateType::class, [
                'widget' => 'single_text',
                //'html5' => true,
                'data' => new \DateTime(),
                'attr'   => ['min' => (new \DateTime())->format('Y-m-d')],
                'mapped'=> false,
                'label' => 'Date du voyage',
                'required' => true
            ])
            ->add('Rechercher', SubmitType::class)
        ;

        $formModifier = function (FormInterface $form, Schedule $schedule = null) {
            $form->add('arrivee', EntityType::class, [
                'class' => Schedule::class,
                'choice_label' => 'arrivee.name',
                'choice_value'  => 'arrivee.id',
                'mapped'=> false,
                'label' => 'Destination',
                'disabled' => $schedule === null,
                'placeholder' => 'Sélectionner la destination',
                'query_builder' => function (ScheduleRepository $s)use($schedule) {
                    if ($schedule) {
                        $res = $s->createQueryBuilder('s')
                        ->join('s.arrivee', 'vi')
                        ->orderBy('vi.name','ASC')
                        ->groupBy('vi.name')
                        ->where('s.depart = :departId')
                        ->andwhere("s.scheduleDate >= '". (new \DateTime())->format('Y-m-d')."'")
                        ->setParameter('departId', $schedule->getDepart()->getId());
                    }else{
                        $res = $s->createQueryBuilder('s')
                        ->join('s.arrivee', 'vi')
                        ->orderBy('vi.name','ASC')
                        ->where('s.depart = :departId')
                        ->andwhere("s.scheduleDate >= '". (new \DateTime())->format('Y-m-d')."'")
                        ->setParameter('departId', 1)
                        ->groupBy('vi.name');
                    };
                    return $res;
                }]);    
        };
        $builder->addEventListener(
            FormEvents::POST_SET_DATA,
            function (FormEvent $event) use ($formModifier) {
                $data = $event->getData();
                $formModifier($event->getForm(), $data->getDepart());
            }
        );


        $builder->get('depart')->addEventListener(
            FormEvents::POST_SUBMIT,
            function (FormEvent $event) use ($formModifier) {
                $depart = $event->getForm()->getData();
                $formModifier($event->getForm()->getParent(), $depart);
            }
        );
        
    }

    // public function configureOptions(OptionsResolver $resolver): void
    // {
    //     $resolver->setDefaults([
    //         'data_class' => SearchData::class,
    //         'method' => 'GET',
    //         'csrf_protection' => false,
    //     ]);
    // }
    public function configureOptions(OptionsResolver $resolver): void
    {
        $resolver->setDefaults([
            'data_class' => Schedule::class,
            //'method' => 'GET',
            'csrf_protection' => false,
        ]);
    }
}
