<?php

namespace App\Repository;

use App\Entity\Passager;
use Doctrine\ORM\Query\Expr\Join;
use Doctrine\Bundle\DoctrineBundle\Repository\ServiceEntityRepository;
use Doctrine\ORM\QueryBuilder;
use Doctrine\Persistence\ManagerRegistry;

/**
 * @extends ServiceEntityRepository<Passager>
 *
 * @method Passager|null find($id, $lockMode = null, $lockVersion = null)
 * @method Passager|null findOneBy(array $criteria, array $orderBy = null)
 * @method Passager[]    findAll()
 * @method Passager[]    findBy(array $criteria, array $orderBy = null, $limit = null, $offset = null)
 */
class PassagerRepository extends ServiceEntityRepository
{
    public function __construct(ManagerRegistry $registry)
    {
        parent::__construct($registry, Passager::class);
    }

    public function save(Passager $entity, bool $flush = false): void
    {
        $this->getEntityManager()->persist($entity);

        if ($flush) {
            $this->getEntityManager()->flush();
        }
    }

    public function remove(Passager $entity, bool $flush = false): void
    {
        $this->getEntityManager()->remove($entity);

        if ($flush) {
            $this->getEntityManager()->flush();
        }
    }



    public function findAllOrderedByAscNameQueryBuilder(): QueryBuilder
    {
        return $this->createQueryBuilder('c')
            ->orderBy('c.firstname', 'ASC');
    }

    public function findManifesteByDate($date, $company): array
    {
        return $this->createQueryBuilder('p')    
            ->leftJoin('App\Entity\Booking', 'b', Join::WITH, 'b.id = p.booking')
            ->leftJoin('App\Entity\User', 'u', Join::WITH, 'u.id = b.user')
            ->leftJoin('App\Entity\Schedule', 's', Join::WITH, 's.id = b.schedule')
            ->andWhere('s.scheduleDate = :date')
            ->andWhere('p.company = :company')
            ->andWhere('b.facture is not null')
            ->setParameter('date', $date)
            ->setParameter('company', $company)
            ->orderBy('p.lastname', 'ASC')
            ->addOrderBy('p.firstname', 'ASC')
            ->getQuery()
            ->getResult()
        ;
    }
//    /**
//     * @return Passager[] Returns an array of Passager objects
//     */
//    public function findByExampleField($value): array
//    {
//        return $this->createQueryBuilder('p')
//            ->andWhere('p.exampleField = :val')
//            ->setParameter('val', $value)
//            ->orderBy('p.id', 'ASC')
//            ->setMaxResults(10)
//            ->getQuery()
//            ->getResult()
//        ;
//    }

//    public function findOneBySomeField($value): ?Passager
//    {
//        return $this->createQueryBuilder('p')
//            ->andWhere('p.exampleField = :val')
//            ->setParameter('val', $value)
//            ->getQuery()
//            ->getOneOrNullResult()
//        ;
//    }
}
