<?php

namespace App\Repository;
use App\Entity\Schedule;
use Doctrine\Bundle\DoctrineBundle\Repository\ServiceEntityRepository;
use Doctrine\ORM\QueryBuilder;
use Doctrine\Persistence\ManagerRegistry;

/**
 * @extends ServiceEntityRepository<Schedule>
 *
 * @method Schedule|null find($id, $lockMode = null, $lockVersion = null)
 * @method Schedule|null findOneBy(array $criteria, array $orderBy = null)
 * @method Schedule[]    findAll()
 * @method Schedule[]    findBy(array $criteria, array $orderBy = null, $limit = null, $offset = null)
 */
class ScheduleRepository extends ServiceEntityRepository
{
    public function __construct(ManagerRegistry $registry)
    {
        parent::__construct($registry, Schedule::class);
    }

    public function save(Schedule $entity, bool $flush = false): void
    {
        $this->getEntityManager()->persist($entity);

        if ($flush) {
            $this->getEntityManager()->flush();
        }
    }

    public function remove(Schedule $entity, bool $flush = false): void
    {
        $this->getEntityManager()->remove($entity);

        if ($flush) {
            $this->getEntityManager()->flush();
        }
    }

//    /**
//     * @return Schedule[] Returns an array of Schedule objects
//     */
//    public function findByExampleField($value): array
//    {
//        return $this->createQueryBuilder('t')
//            ->andWhere('t.exampleField = :val')
//            ->setParameter('val', $value)
//            ->orderBy('t.id', 'ASC')
//            ->setMaxResults(10)
//            ->getQuery()
//            ->getResult()
//        ;
//    }

//    public function findOneBySomeField($value): ?Schedule
//    {
//        return $this->createQueryBuilder('t')
//            ->andWhere('t.exampleField = :val')
//            ->setParameter('val', $value)
//            ->getQuery()
//            ->getOneOrNullResult()
//        ;
//    }


   public function findAllSort($companyId)
   {
    if ($companyId==0){
        $res = $this->createQueryBuilder('sc')
            ->addSelect('b')
            ->join('sc.bus', 'b')
            ->andwhere('sc.scheduleDate >= :dateJour')
            ->andwhere('sc.active = 1')
            ->setParameter('dateJour', new \DateTime())
            ->orderBy('sc.scheduleDate', 'ASC')
            ->getQuery()
            ->getResult()
       ;
    }else{
        $res = $this->createQueryBuilder('sc')
            ->addSelect('b')
            ->join('sc.bus', 'b')
            ->andwhere('sc.scheduleDate >= :dateJour')
            ->andwhere('sc.company = :companyId')
            ->andwhere('sc.active = 1')
            ->setParameter('dateJour', new \DateTime())
            ->setParameter('companyId', $companyId)
            ->orderBy('sc.scheduleDate', 'ASC')
            ->getQuery()
            ->getResult()
       ;

    }
       return $res;
   }
    public function findSchedule($date, $depart, $arrivee, $companyId) {
        if ($companyId==0){
            return $this->createQueryBuilder('sc')
            ->addSelect('b')
            ->join('sc.bus', 'b')
            ->andwhere('sc.depart = :depart')
            ->andwhere('sc.arrivee = :arrivee')
            ->andwhere('sc.scheduleDate >= :dateJour')
            ->andwhere('sc.active = 1')
            ->setParameter('depart', $depart)
            ->setParameter('arrivee', $arrivee)
            ->setParameter('dateJour', $date)
            ->orderBy('sc.scheduleDate','ASC')
            ->getQuery()
            ->getResult();
        }else{
            return $this->createQueryBuilder('sc')
            ->addSelect('b')
            ->join('sc.bus', 'b')
            ->andwhere('sc.depart = :depart')
            ->andwhere('sc.arrivee = :arrivee')
            ->andwhere('sc.scheduleDate >= :dateJour')
            ->andwhere('sc.company = :companyId')
            ->andwhere('sc.active = 1')
            ->setParameter('depart', $depart)
            ->setParameter('arrivee', $arrivee)
            ->setParameter('dateJour', $date)
            ->setParameter('companyId', $companyId)
            ->orderBy('sc.scheduleDate','ASC')
            ->getQuery()
            ->getResult();
        }
    }

    public function findDeparturesOrderedByAscNameQueryBuilder(): QueryBuilder
    {
        return $this->createQueryBuilder('s')
            ->join('s.departure', 'so')
            ->orderBy('so.name','ASC')
            ->groupBy('so.name')
            ->where('s.active = 1');
    }

    public function findDestinationsOrderedByAscNameQueryBuilder($departId): QueryBuilder
    {
        //dd($departId);
        return $this->createQueryBuilder('s')
            ->join('s.destination', 'so')
            ->orderBy('so.name','ASC')
            ->groupBy('so.name')
            ->where('s.departure = :departure')
            ->andwhere('s.active = 1')
            ->setParameter('departure', $departId);
    }


}
